@@ -39,8 +39,8 @@ def parse_args():
     parser = argparse.ArgumentParser(prog='Vicinator', description='Track Microsynteny of a target proteins and its orthologs across genomes')
 
     parser.add_argument('--tabular-ortholog-groups', dest='ogtable', metavar='<orthology_table>',
-                        type=argparse.FileType('rt'), #required=True,
-                    help='path to mapping file with format genom_id<tab>sequence_identifier<tab>ortholog_group_identifier')
+                        type=argparse.FileType('rt'), required=True,
+                    help='path to mapping file with format ortholog_group_id<tab>genome_id<tab>protein_seq_id')
 
     parser.add_argument('--reference', dest='ref_feat_table', metavar='<reference_genome_feature_table_file_path>',
                         type=argparse.FileType('rt'), required=True,
